@@ -1,46 +1,9 @@
-# Copyright (c) 2010 Don Owens <don@regexguy.com>.  All rights reserved.
-#
-# This is free software; you can redistribute it and/or modify it under
-# the Perl Artistic license.  You should have received a copy of the
-# Artistic license with this distribution, in the file named
-# "Artistic".  You may also obtain a copy from
-# http://regexguy.com/license/Artistic
-#
-# This program is distributed in the hope that it will be
-# useful, but WITHOUT ANY WARRANTY; without even the implied
-# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-# PURPOSE.
+# AUTHOR: Don Owens <don@regexguy.com>
+# AUTHOR: Jeff Fearn <Jeff.Fearn@gmail.com>
+# OWNER: 2010 Don Owens <don@regexguy.com>
+# OWNER: 2016 Jeff Fearn <Jeff.Fearn@gmail.com>
+# LICENSE: Perl_5
 
-=pod
-
-=head1 NAME
-
-Pod::POM::View::Restructured - View for Pod::POM that outputs reStructuredText
-
-=head1 SYNOPSIS
-
- use Pod::POM::View::Restructured;
- 
- my $view = Pod::POM::View::Restructured->new;
- my $parser = Pod::POM->new;
- my $pom = $parser->parse_file("$top_dir/lib/Pod/POM/View/Restructured.pm");
- my $out = $pom->present($view);
-
-
-=head1 DESCRIPTION
-
-This module outputs reStructuredText that is expected to be used
-with Sphinx.  Verbatim sections (indented paragraphs) in the POD
-will be output with syntax highlighting for Perl code by default.
-See L</"POD commands specifically for reStructuredText"> for how
-to change this for a particular block.
-
-For a list of changes in recent versions, see the documentation
-for L<Pod::POM::View::Restructured::Changes>.
-
-This module can be downloaded from L<http://www.cpan.org/authors/id/D/DO/DOWENS/>.
-
-=cut
 
 use strict;
 use warnings;
@@ -54,29 +17,6 @@ our $VERSION = '0.03'; # change in POD below!
 
 use base 'Pod::POM::View::Text';
 
-=pod
-
-=head1 METHODS
-
-=head2 C<new(\%params)>
-
-Constructor.  \%params is optional.  If present, the following keys are valid:
-
-=over 4
-
-=item C<callbacks>
-
-See documentation below for C<convert_file()>.
-
-=item C<namespace>
-
-If a namespace is declared then links to that namespace are
-converted to cross references and an anchor is added for each
-head tag.
-
-=back
-
-=cut
 
 sub new {
     my ($class, $params) = @_;
@@ -92,22 +32,6 @@ sub new {
     return $self;
 }
 
-=pod
-
-=head2 C<convert_file($source_file, $title, $dest_file, $callbacks)>
-
-Converts the POD in C<$source_file> to reStructuredText.  If
-C<$dest_file> is defined, it writes the output there.  If
-C<$title> is defined, it is used for the title of the document.
-Otherwise, an attempt is made to infer the title from the NAME
-section (checks if the body looks like C</\A\s*(\w+(?:::\w+)+)\s+-\s+/s>).
-
-Returns the output as a string.
-
-C<$source_file> and C<$dest_file> can be either file names or file
-handles.
-
-=cut
 sub convert_file {
     my ($self, $source_file, $title, $dest_file, $callbacks) = @_;
 
@@ -160,71 +84,6 @@ sub convert_file {
     return $rv;
 }
 
-=pod
-
-=head2 C<convert_files($file_spec, $index_file, $index_title, $out_dir)>
-
-Converts the files given in C<$file_spec> to reStructuredText.
-If C<$index_file> is provided, it is the path to the index file
-to be created (with a table of contents pointing to all of the
-files created).  If C<$index_title> is provided, it is used as
-the section title for the index file.  C<$out_dir> is the
-directory the generated files will be written to.
-
-C<$file_spec> is a reference to an array of hashes specifying
-attributes for each file to be converted.  The valid keys are:
-
-=over 4
-
-=item C<source_file>
-
-File to convert.
-
-=item C<dest_file>
-
-File to output the reStructuredText.  If not provided, a file
-name will be generated based on the title.
-
-=item C<title>
-
-Section title for the generated reStructuredText.  If not
-provided, an attempt will be made to infer the title from the
-NAME section in the POD, if it exists.  As a last resort, a title
-will be generated that looks like "section_(\d+)".
-
-=item C<callbacks>
-
-A reference to a hash containing names and the corresponding callbacks.
-
-Currently the only valid callback is C<link>.  It is given the
-text inside a LE<lt>E<gt> section from the POD, and is expected to return a
-tuple C<($url, $label)>.  If the value returned for C<$label> is
-undefined, the value of C<$url> is used as the label.
-
-=item C<no_toc>
-
-Causes the item to not be printed to the index or return in the C<toc> field.
-
-=back
-
-This method returns a hash ref with a table of contents (the
-C<toc> field) suitable for a reStructuredText table of contents.
-
-E.g.,
-
- my $conv = Pod::POM::View::Restructured->new;
- 
- my $files = [
-              { source_file => "$base_dir/Restructured.pm" },
-              { source_file => "$base_dir/DWIW.pm" },
-              { source_file => "$base_dir/Wrapper.pm" },
-             ];
- 
- 
- my $rv = $conv->convert_files($files, "$dest_dir/index.rst", 'My Big Test', $dest_dir);
-
-
-=cut
 sub convert_files {
     my ($self, $file_spec, $index_file, $index_title, $out_dir) = @_;
 
@@ -315,9 +174,7 @@ sub _get_file_handle {
 sub view_pod {
     my ($self, $node) = @_;
 
-    my $content = ".. highlight:: perl\n\n";
-    
-    return $content . $node->content()->present($self);
+    return $node->content()->present($self);
 }
 
 sub _generic_head {
@@ -521,7 +378,7 @@ sub view_for {
             return '';
         }
 
-        return '';
+        return "\n". $node->text() . "\n\n";
     }
 
     return $self->SUPER::view_for($node);
@@ -644,8 +501,142 @@ sub _url_encode {
 }
 
 
+
+1;
+
+# Local Variables: #
+# mode: perl #
+# tab-width: 4 #
+# indent-tabs-mode: nil #
+# cperl-indent-level: 4 #
+# perl-indent-level: 4 #
+# End: #
+# vim:set ai si et sta ts=4 sw=4 sts=4:
+
+__END__
+
 =pod
 
+=head1 NAME
+
+Pod::POM::View::Restructured - View for Pod::POM that outputs reStructuredText
+
+=head1 SYNOPSIS
+
+ use Pod::POM::View::Restructured;
+ 
+ my $view = Pod::POM::View::Restructured->new;
+ my $parser = Pod::POM->new;
+ my $pom = $parser->parse_file("$top_dir/lib/Pod/POM/View/Restructured.pm");
+ my $out = $pom->present($view);
+
+=head1 DESCRIPTION
+
+This module outputs reStructuredText that is expected to be used
+with Sphinx.  Verbatim sections (indented paragraphs) in the POD
+will be output with syntax highlighting for Perl code by default.
+See L</"POD commands specifically for reStructuredText"> for how
+to change this for a particular block.
+
+For a list of changes in recent versions, see the documentation
+for L<Pod::POM::View::Restructured::Changes>.
+
+This module can be downloaded from L<http://www.cpan.org/authors/id/D/DO/DOWENS/>.
+
+=head1 METHODS
+
+=head2 C<new(\%params)>
+
+Constructor.  \%params is optional.  If present, the following keys are valid:
+
+=over 4
+
+=item C<callbacks>
+
+See documentation below for C<convert_file()>.
+
+=item C<namespace>
+
+If a namespace is declared then links to that namespace are
+converted to cross references and an anchor is added for each
+head tag.
+
+=back
+
+=head2 C<convert_file($source_file, $title, $dest_file, $callbacks)>
+
+Converts the POD in C<$source_file> to reStructuredText.  If
+C<$dest_file> is defined, it writes the output there.  If
+C<$title> is defined, it is used for the title of the document.
+Otherwise, an attempt is made to infer the title from the NAME
+section (checks if the body looks like C</\A\s*(\w+(?:::\w+)+)\s+-\s+/s>).
+
+Returns the output as a string.
+
+C<$source_file> and C<$dest_file> can be either file names or file
+handles.
+
+=head2 C<convert_files($file_spec, $index_file, $index_title, $out_dir)>
+
+Converts the files given in C<$file_spec> to reStructuredText.
+If C<$index_file> is provided, it is the path to the index file
+to be created (with a table of contents pointing to all of the
+files created).  If C<$index_title> is provided, it is used as
+the section title for the index file.  C<$out_dir> is the
+directory the generated files will be written to.
+
+C<$file_spec> is a reference to an array of hashes specifying
+attributes for each file to be converted.  The valid keys are:
+
+=over 4
+
+=item C<source_file>
+
+File to convert.
+
+=item C<dest_file>
+
+File to output the reStructuredText.  If not provided, a file
+name will be generated based on the title.
+
+=item C<title>
+
+Section title for the generated reStructuredText.  If not
+provided, an attempt will be made to infer the title from the
+NAME section in the POD, if it exists.  As a last resort, a title
+will be generated that looks like "section_(\d+)".
+
+=item C<callbacks>
+
+A reference to a hash containing names and the corresponding callbacks.
+
+Currently the only valid callback is C<link>.  It is given the
+text inside a LE<lt>E<gt> section from the POD, and is expected to return a
+tuple C<($url, $label)>.  If the value returned for C<$label> is
+undefined, the value of C<$url> is used as the label.
+
+=item C<no_toc>
+
+Causes the item to not be printed to the index or return in the C<toc> field.
+
+=back
+
+This method returns a hash ref with a table of contents (the
+C<toc> field) suitable for a reStructuredText table of contents.
+
+E.g.,
+
+ my $conv = Pod::POM::View::Restructured->new;
+ 
+ my $files = [
+              { source_file => "$base_dir/Restructured.pm" },
+              { source_file => "$base_dir/DWIW.pm" },
+              { source_file => "$base_dir/Wrapper.pm" },
+             ];
+ 
+ 
+ my $rv = $conv->convert_files($files, "$dest_dir/index.rst", 'My Big Test', $dest_dir);
+
 =head1 POD commands specifically for reStructuredText
 
 The following sequences can be used in POD to request actions specifically for this module.
@@ -680,7 +671,6 @@ B<Need to document:>
 
 =back
 
-
 =head1 TODO
 
 =over 4
@@ -706,29 +696,6 @@ to invoke a command in reStructuredText by accident.
 
 Inherits from L<Pod::POM::View::Text> that comes with the Pod::POM distribution.
 
-=head1 AUTHORS
-
-=over
-
-=item Don Owens <don@regexguy.com>
-
-=item Jeff Fearn <Jeff.Fearn@gmail.com>
-
-=back
-
-=head1 LICENSE AND COPYRIGHT
-
-Copyright (c) 2010 Don Owens <don@regexguy.com>.  All rights reserved.
-Copyright (c) 2016 Jeff Fearn <Jeff.Fearn@gmail.com>.  All rights reserved.
-
-This is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.  See perlartistic.
-
-This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-PURPOSE.
-
 =head1 SEE ALSO
 
 L<Pod::POM>
@@ -747,15 +714,16 @@ Pygments (used by Sphinx for syntax highlighting): L<http://pygments.org/>
 
 0.03
 
+=head1 AUTHORS
+
+Don Owens <don@regexguy.com>
+
+Jeff Fearn <Jeff.Fearn@gmail.com>
+
+=head1 COPYRIGHT
+
+This software is copyright (c) 2010 by Don Owens <don@regexguy.com>, and 2016 by Jeff Fearn <Jeff.Fearn@gmail.com>.
+
+This software is available under the same terms as the perl 5 programming language system itself.
+
 =cut
-
-1;
-
-# Local Variables: #
-# mode: perl #
-# tab-width: 4 #
-# indent-tabs-mode: nil #
-# cperl-indent-level: 4 #
-# perl-indent-level: 4 #
-# End: #
-# vim:set ai si et sta ts=4 sw=4 sts=4:
